@@ -1,6 +1,5 @@
 /* vim: ft=c:set si:set fileencoding=iso-8859-1
  */
-#line 9 "konto_check_h.lx"
 
 /*
  * ##########################################################################
@@ -82,13 +81,16 @@
 
 #define FLESSA_KORREKTUR 1
 
-/* Zum Gueltigkeitstermin 4. Maerz 2013 erfolgen Aenderungen der
- * Pruefzifferberechnungsmethoden C6 und D1; mit dem folgenden Makro werden
- * diese nderungen aktiviert.
- */
-#define PZ_METHODEN_2013_03_04 1
+/* IBAN-Regeln benutzen (gltig ab 3.6.2013) */
+#define USE_IBAN_RULES 1
 
 
+/* Debug-Version fr iban_gen in Perl aktivieren (zur Ausgabe der benutzten
+ * Prfziffermethode in iban_gen()). Dies ist nur mglich, falls das Makro
+ * DEBUG auf 1 gesetzt ist.
+ */
+#define PERL_IBAN_DBG 1
+
 /* Das Makro DEFAULT_ENCODING legt die Ausgabe-Kodierung fr die Funktion
  * kto_check_retval2txt() und die Blocks Name, Kurzname und Ort aus der
  * LUT-Datei fest. Die folgenden Werte sind mglich:
@@ -221,7 +223,7 @@
  * # aktiviert.                                                         #
  * ######################################################################
  */
-#define AWK_ADD_MICROTIME 0
+#define AWK_ADD_MICROTIME 1
 
 
 /*
@@ -299,6 +301,7 @@
 #define LUT2_OWN_IBAN                22
 #define LUT2_VOLLTEXT_TXT            23
 #define LUT2_VOLLTEXT_IDX            24
+#define LUT2_IBAN_REGEL              25
 
 #define LUT2_2_BLZ                  101
 #define LUT2_2_FILIALEN             102
@@ -324,6 +327,7 @@
 #define LUT2_2_OWN_IBAN             122
 #define LUT2_2_VOLLTEXT_TXT         123
 #define LUT2_2_VOLLTEXT_IDX         124
+#define LUT2_2_IBAN_REGEL           125
 
 #define LUT2_DEFAULT                501
 
@@ -340,6 +344,13 @@ extern const char *lut2_feld_namen[256];
  */
 
 #undef FALSE
+#define IBAN_INVALID_RULE                     -128
+#define IBAN_AMBIGUOUS_KTO                    -127
+#define IBAN_RULE_NOT_IMPLEMENTED             -126
+#define IBAN_RULE_UNKNOWN                     -125
+#define NO_IBAN_CALCULATION                   -124
+#define OLD_BLZ_OK_NEW_NOT                    -123
+#define LUT2_IBAN_REGEL_NOT_INITIALIZED       -122
 #define INVALID_IBAN_LENGTH                   -121
 #define LUT2_NO_ACCOUNT_GIVEN                 -120
 #define LUT2_VOLLTEXT_INVALID_CHAR            -119
@@ -477,7 +488,14 @@ extern const char *lut2_feld_namen[256];
 #define OK_SLOT_CNT_MIN_USED                    13
 #define SOME_KEYS_NOT_FOUND                     14
 #define LUT2_KTO_NOT_CHECKED                    15
-#line 294 "konto_check_h.lx"
+#define LUT2_OK_WITHOUT_IBAN_RULES              16
+#define OK_NACHFOLGE_BLZ_USED                   17
+#define OK_KTO_REPLACED                         18
+#define OK_BLZ_REPLACED                         19
+#define OK_BLZ_KTO_REPLACED                     20
+#define OK_IBAN_WITHOUT_KC_TEST                 21
+#define OK_INVALID_FOR_IBAN                     22
+#define OK_HYPO_REQUIRES_KTO                    23
 
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
@@ -553,8 +571,8 @@ typedef struct{
  * # Dieser Parameter gibt an, wieviele Slots das Inhaltsverzeichnis einer  #
  * # LUT-Datei mindestens haben soll. Fr jeden Block in der LUT-Datei wird #
  * # ein Slot im Inhaltsverzeichnis bentigt; bei einer LUT-Datei mit allen #
- * # Eintrgen (Level 9) sind das 19 Slots, falls zwei Datenstze in der    #
- * # Datei gehalten werden sollen, 38 (inklusive Indexblocks).              #
+ * # Eintrgen (Level 9) sind das 23 Slots, falls zwei Datenstze in der    #
+ * # Datei gehalten werden sollen, 46 (inklusive Indexblocks).              #
  * #                                                                        #
  * # Das Slotverzeichnis ist eine relativ einfache Datenstruktur; es        #
  * # enthlt fr jeden Slot nur drei 4 Byte-Integers (Typ, Offset und       #
@@ -569,7 +587,7 @@ typedef struct{
  * #                                                                        #
  * ##########################################################################
  */
-#define SLOT_CNT_MIN 40
+#define SLOT_CNT_MIN 50
 
 /*
  * ##########################################################################
@@ -755,6 +773,7 @@ DLL_EXPORT int get_lut_info_t(char **info,char *lut_name,KTO_CHK_CTX *ctx);
  * ######################################################################
  */
 DLL_EXPORT const char *get_kto_check_version(void);
+DLL_EXPORT const char *get_kto_check_version_x(int mode);
 
 /*
  * ######################################################################
@@ -857,6 +876,8 @@ DLL_EXPORT int lut_loeschung_i(int b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_nachfolge_blz(char *b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_nachfolge_blz_i(int b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_keine_iban_berechnung(char *iban_blacklist,char *lutfile,int set);
+DLL_EXPORT int lut_iban_regel(char *b,int zweigstelle,int *retval);
+DLL_EXPORT int lut_iban_regel_i(int b,int zweigstelle,int *retval);
 
 /*
  * ######################################################################
@@ -920,6 +941,7 @@ DLL_EXPORT int lut_cleanup(void);
 DLL_EXPORT int iban_check(char *iban,int *retval);
 DLL_EXPORT const char *iban2bic(char *iban,int *retval,char *blz,char *kto);
 DLL_EXPORT char *iban_gen(char *kto,char *blz,int *retval);
+DLL_EXPORT char *iban_bic_gen(char *blz,char *kto,const char **bicp,char *blz2,char *kto2,int *retval);
 DLL_EXPORT int ipi_gen(char *zweck,char *dst,char *papier);
 DLL_EXPORT int ipi_check(char *zweck);
 
